@@ -1,7 +1,8 @@
 import base64
-import tempfile
+import http.server
+import random
+import socketserver
 import uuid
-import webbrowser
 
 from jinja2 import BaseLoader, Environment
 
@@ -81,25 +82,63 @@ class MailCarrier:
 
 
 class MailCarrierTemplate:
-    def __init__(self):
+    def __init__(self, port: int = None):
         self.http = Http()
         self.severino_api_url = SEVERINO_API_URL
         self.path = "/mail-carrier/mail-template"
+        self.port = port
+        if not port:
+            self.port = random.randint(8400, 8700)
 
     def test_template(self, template_path: str, context_vars: dict):
-        html = ""
+        class HttpRequestHandler(http.server.SimpleHTTPRequestHandler):
+            def do_GET(self):
+                if self.path == "/mail/template":
+                    html = ""
 
-        with open(template_path, "rb") as file:
-            html = file.read()
+                    # Sending an '200 OK' response
+                    self.send_response(200)
 
-        template = Environment(loader=BaseLoader()).from_string(html.decode("utf-8"))
+                    # Setting the header
+                    self.send_header("Content-type", "text/html")
 
-        temp_file = tempfile.NamedTemporaryFile(suffix=".html", delete=False)
-        temp_file.write(str(template.render(**context_vars)).encode("utf-8"))
-        temp_file.flush()
-        temp_file.close()
+                    # Whenever using 'send_header', you also have to call 'end_headers'
+                    self.end_headers()
 
-        webbrowser.open_new_tab(temp_file.name)
+                    with open(template_path, "rb") as file:
+                        html = file.read()
+
+                    template = Environment(loader=BaseLoader()).from_string(
+                        html.decode("utf-8")
+                    )
+
+                    # Writing the HTML contents with UTF-8
+                    self.wfile.write(
+                        bytes(str(template.render(**context_vars)), "utf8")
+                    )
+
+                return
+
+        # Create an object of the above class
+        handler_object = HttpRequestHandler
+
+        PORT = self.port
+
+        severino_server = socketserver.TCPServer(("", PORT), handler_object)
+
+        print("\n")
+
+        print(
+            "Severino SDK server started at http://localhost:"
+            + str(PORT)
+            + "/mail/template"
+        )
+
+        try:
+            severino_server.serve_forever()
+            severino_server.shutdown()
+        except:
+            severino_server.shutdown()
 
     def update(self, template_name: str, template_path: str):
         template_data = None
